==> vdocipher_flutter-2.0.0.tar.gz: android/src/main/java/com/vdocipher/flutter/vdoplayer/VdoInitParamsToMap.java <==
package com.vdocipher.flutter.vdoplayer;

import com.vdocipher.aegis.player.VdoInitParams;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class VdoInitParamsToMap {
    public static Map<String, Object> convert(VdoInitParams vdoInitParams) {
        Map<String, Object> embedInfo = new HashMap<>();
        embedInfo.put("mediaId", vdoInitParams.mediaId);
        embedInfo.put("playbackInfo", vdoInitParams.playbackInfo);
        embedInfo.put("otp", vdoInitParams.otp);
        embedInfo.put("offline", vdoInitParams.offlinePlayback);

        Map<String, Object> embedInfoOptions = new HashMap<>();
        embedInfoOptions.put("safetyNetApiKey", vdoInitParams.safetyNetApiKey);
        embedInfoOptions.put("preferredCaptionsLanguage", vdoInitParams.preferredCaptionsLanguage);
        embedInfoOptions.put("startPosition", vdoInitParams.startTimeMs);
        embedInfoOptions.put("endPosition", vdoInitParams.endTimeMs);
        embedInfoOptions.put("resumePosition", vdoInitParams.resumeTimeMs);
        embedInfoOptions.put("maxVideoBitrateKbps", vdoInitParams.maxVideoBitrateKbps);
        embedInfoOptions.put("bufferingGoalMs", vdoInitParams.bufferingGoalMs);
        List<String> techOverrides = new ArrayList<>(Arrays.asList(vdoInitParams.techOverride));
        embedInfoOptions.put("techOverride", techOverrides);
        embedInfoOptions.put("disableAnalytics", vdoInitParams.disableAnalytics);
        embedInfoOptions.put("autoplay", vdoInitParams.autoplay);
        embedInfoOptions.put("forceLowestBitrate", vdoInitParams.forceLowestBitrate);
        embedInfoOptions.put("forceHighestSupportedBitrate", vdoInitParams.forceHighestSupportedBitrate);
        embedInfoOptions.put("allowAutoResume", vdoInitParams.isAutoResumeEnabled);
        embedInfoOptions.put("configMap", vdoInitParams.configMap);
        embedInfoOptions.put("playerConfigId", vdoInitParams.playerConfigId);
        embedInfo.put("embedInfoOptions", embedInfoOptions);

        return embedInfo;
    }
}

==> vdocipher_flutter-2.2.0.tar.gz: android/src/main/java/com/vdocipher/flutter/vdoplayer/VdoInitParamsToMap.java <==
package com.vdocipher.flutter.vdoplayer;

import com.vdocipher.aegis.player.VdoInitParams;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class VdoInitParamsToMap {
    public static Map<String, Object> convert(VdoInitParams vdoInitParams) {
        Map<String, Object> embedInfo = new HashMap<>();
        embedInfo.put("mediaId", vdoInitParams.mediaId);
        embedInfo.put("playbackInfo", vdoInitParams.playbackInfo);
        embedInfo.put("otp", vdoInitParams.otp);
        embedInfo.put("offline", vdoInitParams.offlinePlayback);

        Map<String, Object> embedInfoOptions = new HashMap<>();
        embedInfoOptions.put("safetyNetApiKey", vdoInitParams.safetyNetApiKey);
        embedInfoOptions.put("preferredCaptionsLanguage", vdoInitParams.preferredCaptionsLanguage);
        embedInfoOptions.put("startPosition", vdoInitParams.startTimeMs);
        embedInfoOptions.put("endPosition", vdoInitParams.endTimeMs);
        embedInfoOptions.put("resumePosition", vdoInitParams.resumeTimeMs);
        embedInfoOptions.put("maxVideoBitrateKbps", vdoInitParams.maxVideoBitrateKbps);
        embedInfoOptions.put("bufferingGoalMs", vdoInitParams.bufferingGoalMs);
        List<String> techOverrides = new ArrayList<>(Arrays.asList(vdoInitParams.techOverride));
        embedInfoOptions.put("techOverride", techOverrides);
        embedInfoOptions.put("disableAnalytics", vdoInitParams.disableAnalytics);
        embedInfoOptions.put("autoplay", vdoInitParams.autoplay);
        embedInfoOptions.put("forceLowestBitrate", vdoInitParams.forceLowestBitrate);
        embedInfoOptions.put("forceHighestSupportedBitrate", vdoInitParams.forceHighestSupportedBitrate);
        embedInfoOptions.put("allowAutoResume", vdoInitParams.isAutoResumeEnabled);
        embedInfoOptions.put("configMap", vdoInitParams.configMap);
        embedInfoOptions.put("customPlayerId", vdoInitParams.playerConfigId);
        embedInfo.put("embedInfoOptions", embedInfoOptions);

        return embedInfo;
    }
}
